@@ -6,21 +6,18 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
+package Soar::Production::Printer;
+# ABSTRACT: Print Soar productions
 use strict;
 use warnings;
 
-# ABSTRACT: Print Soar productions
-package Soar::Production::Printer;
-
-use parent 'Exporter';
-our @EXPORT = qw(tree_to_text);
+our $VERSION = '0.03'; # VERSION
 
 use Soar::Production::Parser;
-use Data::Dumper;
 use Carp;
-# use Test::More tests => 1;
-
-our $VERSION = '0.02'; # VERSION
+use Exporter::Easy (
+	OK => [qw(tree_to_text)]
+);
 
 #default behavior is to read the input Soar file and output another one; worthless except for testing
 _run(shift) unless caller;
@@ -36,26 +33,26 @@ sub _run {
     my $text = tree_to_text($$trees[0]);
 	my $tree = $parser->parse_text($text)
 		or croak 'illegal production printed';
-		
+
 	print $text;
 	return;
 }
 
 sub tree_to_text{
 	my ($tree) = @_;
-	
+
     #traverse tree and construct the Soar production text
     my $text = 'sp {';
 
     $text .= _name( $tree->{name} );
     $text .= _doc( $tree->{doc} );
     $text .= _flags( $tree->{flags} );
-	
+
     $text .= _LHS( $tree->{LHS} );
 	$text .= "\n-->\n\t";
     $text .= _RHS( $tree->{RHS} );
 	$text .= "\n}";
-	
+
 	return $text;
 }
 
@@ -83,65 +80,64 @@ sub _flags {
 
 sub _LHS {
 	my $LHS = shift;
-	return join "\n\t", 
+	return join "\n\t",
 		map { _condition($_) } @{ $LHS->{conditions} };
 }
 
 sub _condition {
 	my $condition = shift;
 	my $text = '';
-	
+
 	$text .= '-'
 		if($condition->{negative} eq 'yes');
-		
+
 	$text .= _positive_condition( $condition->{condition} );
-	
+
 	return $text;
 }
 
 sub _positive_condition {
 	my $condition = shift;
-	my $text = '';
-	
+
 	return _conjunction( $condition->{conjunction} )
 		if($condition->{conjunction});
-		
+
 	return _condsForOneId($condition);
 }
 
 sub _condsForOneId {
 	my $condsForOneId = shift;
 	my $text = '(';
-	my ($type, $idTest, $attrValueTests) = 
+	my ($type, $idTest, $attrValueTests) =
 		(
-			$condsForOneId->{condType}, 
-			$condsForOneId->{idTest}, 
+			$condsForOneId->{condType},
+			$condsForOneId->{idTest},
 			$condsForOneId->{attrValueTests}
 		);
-		
+
 	$text .= $type
 		if(defined $type);
-	
+
 	$text .= ' ' . _test($idTest)
 		if(defined $idTest);
-		
+
 	if($#$attrValueTests != -1){
 		$text .= ' ';
 		$text .= join ' ', map { _attrValueTests($_) } @$attrValueTests;
 	}
-	
+
 	$text .= ')';
 	return $text;
 }
 
 sub _test {
 	my $test = shift;
-	
+
 	if(exists $test->{conjunctiveTest}){
-		return _conjunctiveTest( 
+		return _conjunctiveTest(
 			$test->{conjunctiveTest} );
 	}
-	
+
 	return _simpleTest( $test->{simpleTest} );
 }
 
@@ -151,6 +147,7 @@ sub _conjunctiveTest {
 	$text .= join ' ',
 		map { _simpleTest($_) } @$conjTest;
 	$text .= '}';
+	return $text;
 }
 
 sub _simpleTest {
@@ -172,11 +169,11 @@ sub _disjunctionTest {
 
 sub _relationalTest {
 	my $test = shift;
-	
+
 	my $text = _relation( $test->{relation} );
 	$text .= ' ';
 	$text .= _singleTest( $test->{test} );
-	
+
 	return $text;
 }
 
@@ -194,7 +191,7 @@ sub _singleTest {
 
 sub _attrValueTests {
 	my $attrValuetests = shift;
-	my ($negative, $attrs, $values) = 
+	my ($negative, $attrs, $values) =
 		(
 			$attrValuetests->{negative},
 			$attrValuetests->{attrs},
@@ -204,7 +201,7 @@ sub _attrValueTests {
 	$text .= '-'
 		if($negative eq 'yes');
 	$text .= _attTest($attrs);
-	
+
 	if($#$values != -1){
 		$text .= ' ';
 		$text .= join ' ', map { _valueTest($_) } @$values;
@@ -222,17 +219,17 @@ sub _attTest {
 sub _valueTest {
 	my $valueTest = shift;
 	my $text = '';
-	
+
 	if(exists $valueTest->{test}){
 		$text = _test( $valueTest->{test} );
 	}else{
 		#condsForOneId
 		$text = _condsForOneId($valueTest->{conds});
 	}
-	
+
 	$text .= '+'
 		if($valueTest->{'+'} eq 'yes');
-	
+
 	return $text
 }
 
@@ -259,7 +256,7 @@ sub _action {
 	if(exists $action->{funcCall}){
 		return _funcCall($action->{funcCall});
 	}
-	
+
 	my $text = '(';
 	$text .= _variable($action->{variable});
 	$text .= ' ';
@@ -271,19 +268,19 @@ sub _action {
 
 sub _attrValueMake {
 	my $attrValueMake = shift;
-	my ($attr, $valueMake) = 
+	my ($attr, $valueMake) =
 		($attrValueMake->{attr}, $attrValueMake->{valueMake});
-	
+
 	my $text = _attr($$attr[0]);
 	if($#$attr != 0){
 		$text .= '.';
-		$text .= join '.', 
+		$text .= join '.',
 			map { _variableOrSymConstant($_) } @$attr[1..$#$attr];
 	}
-	
+
 	$text .= ' ';
 	$text .= join ' ', map{_valueMake($_)} @$valueMake;
-	
+
 	return $text;
 }
 
@@ -297,12 +294,12 @@ sub _variableOrSymConstant {
 	return _variable($vOs->{variable})
 		if(exists $vOs->{variable});
 	return _symConstant($vOs);
-	
+
 }
 
 sub _valueMake {
 	my $valueMake = shift;
-	my ($rhsValue, $preferences) = 
+	my ($rhsValue, $preferences) =
 		($valueMake->{rhsValue}, $valueMake->{preferences});
 	my $text = _rhsValue($rhsValue);
 	#there will always be at least one preference; '+' is default
@@ -323,10 +320,10 @@ sub _preference {
 #variable | constant | "(crlf)" | funcCall
 sub _rhsValue {
 	my $rhsValue = shift;
-	
+
 	return '(crlf)'
 		if($rhsValue eq '(crlf)');
-		
+
 	if(exists $rhsValue->{variable}){
 		return _variable($rhsValue->{variable});
 	}
@@ -342,8 +339,8 @@ sub _rhsValue {
 #(write |Hello World| |hello again|)
 sub _funcCall {
 	my $funcCall = shift;
-	
-	my ($name, $args) = 
+
+	my ($name, $args) =
 		(_funcName($funcCall->{function}), $funcCall->{args});
 	my $text = '(' . $name;
 	if($#$args != -1){
@@ -356,7 +353,7 @@ sub _funcCall {
 # arithmetic operator (+ - * /) or a symConstant, being the name of some function
 sub _funcName {
 	my $funcName = shift;
-	
+
 	if(ref $funcName eq 'HASH'){
 		return _symConstant($funcName);
 	}
@@ -371,7 +368,7 @@ sub _variable {
 sub _constant {
 	my $constant = shift;
 	my ($type, $value) = ($constant->{type}, $constant->{constant});
-	
+
 	return _symConstant($value) if($type eq 'sym');
 	return _int($value) if($type eq 'int');
 	return _float($value);#only other type is 'float'
@@ -401,7 +398,7 @@ sub _string {
 
 sub _quoted {
 	my $text = shift;
-	
+
 	#escape vertical bars
 	$text =~ s/\|/\\|/g;
 	return '|' . $text . '|';
@@ -419,18 +416,17 @@ Soar::Production::Printer - Print Soar productions
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
   use Soar::Production::Parser;
-  use Soar::Production::Printer;
-  use Data::Dumper;
-  
+  use Soar::Production::Printer qw(tree_to_text);
+
   #read in a series of productions from a file
   my $parser = Soar::Production::Parser->new;
   my @trees=$parser->parse_file("foo.soar");
-  
+
   #print each of the productions to standard out
   for my $prod(@trees){
 	print tree_to_text($prod);
@@ -440,13 +436,15 @@ version 0.02
 
 This module can be used to print production parse trees produced by Soar::Production::parser. Use the function C<tree_to_text> to accomplish this.
 
-Printing is accomplished by traversing the input structure exactly as it is specified by the grammar used by Soar::Production::Parser. 
+Printing is accomplished by traversing the input structure exactly as it is specified by the grammar used by Soar::Production::Parser.
 
 =head1 NAME
 
 Soar::Production::pRINT - Perl extension for printing Soar productions
 
-=head1 METHODS
+=head1 EXPORTED FUNCTIONS
+
+The following may be exported to the caller's namespace.
 
 =head2 C<tree_to_text>
 
